@@ -66,14 +66,35 @@ def read_bytes(file_name, start_num, size, is_image=True):
 
 def read_json(file_path):
     d = open(file_path).read().split('\n')
-    d = [json.loads(i)  for i in d if i.strip()]
-    return d
+    res = []
+    for line in d:
+        try:
+            res.append(json.loads(i))
+        except:
+            continue
+    print('all {} lines, success {} lines'.format(len(d), len(res)))
 
-def write_json(file_path, dat):
-    with open(file_path, 'a') as f:
+    return res
+
+def write_json(file_path, dat, mode='a'):
+    with open(file_path, mode) as f:
         for i in dat:
             f.write(json.dumps(i, ensure_ascii=False) + '\n')
 
+
+def get_resolution(resolution):
+    resolutions = [('16:9', 16./9), ('4:3', 4./3), ('1:1', 1), ('3:4', 3./4), ('9:16', 9./16)]
+ 
+    Bmatch, Bdistance = '', 19
+    ratio = resolution[0] / resolution[1]
+    if True:
+        for match, distance in resolutions:
+            if abs(ratio - distance) < Bdistance:
+                Bmatch = match
+                Bdistance = abs(ratio - distance)
+    return Bmatch
+
+
 import os
 d = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'map.pkl')
 
